#ifndef CENTRAL_H
#define CENTRAL_H

#include <QWidget>

class QLineEdit;
class QCheckBox;
class QPushButton;
class QComboBox;


class Central : public QWidget
{
    Q_OBJECT
public:
    explicit Central(QWidget *parent = 0);

    QLineEdit *stringa1LineEdit;
    QLineEdit *stringa2LineEdit;
    QLineEdit *stringa3LineEdit;
    QLineEdit *stringa4LineEdit;
    QLineEdit *stringa5LineEdit;
    QLineEdit *stringa6LineEdit;
    QLineEdit *stringa7LineEdit;
    QLineEdit *stringa8LineEdit;

    QCheckBox *stringa1CheckBox;
    QCheckBox *stringa2CheckBox;
    QCheckBox *stringa3CheckBox;
    QCheckBox *stringa4CheckBox;
    QCheckBox *stringa5CheckBox;
    QCheckBox *stringa6CheckBox;
    QCheckBox *stringa7CheckBox;
    QCheckBox *stringa8CheckBox;

    QCheckBox *dataCheckBox;
    QComboBox *dayBox;
    QComboBox *monthBox;
    QComboBox *yearBox;

    QCheckBox *dataRCheckBox;
    QComboBox *dataRComboBox;

    QPushButton *deleteButton;
    QPushButton *infoButton;
    QCheckBox *backgroundCheckBox;



    ~Central();



private:
    void readSettings();


signals:


public slots:

    void deleteButtonClicked();
    void writeSettings();
    void infoClicked();

};

#endif // CENTRAL_H
